// Trinket/Gemma + LED matrix backpack jewelry.  Plays animated
// sequence on LED matrix.  Press reset button to display again,
// or add optional momentary button between pin #1 and +V.
// (ATtiny85)

#define BRIGHTNESS   5 // 0=min, 15=max
#define I2C_ADDR   0x70 // Edit if backpack A0/A1 jumpers set

#include <Wire.h>
#include <avr/wdt.h>
#include <avr/power.h>
#include <avr/sleep.h>
#include "tools.h"
#include "frames.h"
#include "anims.h"

void setup() {
  randomSeed(analogRead(0));
  power_timer1_disable();    // Disable unused peripherals
  power_adc_disable();       // to save power
  PCMSK |= _BV(PCINT1);      // Set change mask for pin 1
  Wire.begin();              // I2C init
  clear();                   // Blank display
  ledCmd(0x21);              // Turn on oscillator
  ledCmd(0xE0 | BRIGHTNESS); // Set brightness
  ledCmd(0x81);              // Display on, no blink
}
void loop() {
  const uint8_t* anim;

  //Select animation
  switch (random(15)) {
    case 0:
      anim = anim_tama1;
      break;
    case 1:
      anim = anim_alien2;
      break;
    case 2:
      anim = anim_heart1;
      break;
    case 3:
      anim = anim_heart2;
      break;
    case 4:
      anim = anim_polli1;
      break;
    case 5:
      anim = anim_polli2;
      break;
    case 6:
      anim = anim_kaboom;
      break;
    case 7:
      anim = anim_ghst;
      break;
    case 8:
      anim = anim_snake;
      break;
    case 9:
      anim = anim_dog;
      break;
    case 10:
      anim = anim_rball;
      break;
    case 11:
      anim = anim_bomb;
      break;
    case 12:
      anim = anim_smiley;
      break;
    case 13:
      anim = anim_pokeball;
      break;
    case 14:
      anim = anim_snow;
      break;
    default:
      return;
  }

  for (int i = 0; 1; i += 2) { // For each frame...
    uint8_t frameN = pgm_read_byte(anim + i);
    uint8_t delayN = pgm_read_byte(anim + i + 1);
    if (frameN == 0 && delayN == 0)
      break;
    Wire.beginTransmission(I2C_ADDR);
    Wire.write(0);                  // Start address
    const uint8_t* frame = frames + (frameN * 8); //+(pgm_read_byte(anim[i])*8);
    for (uint8_t j = 0; j < 8; j++) { // 8 rows...
      Wire.write(pgm_read_byte(&reorder[pgm_read_byte(frame + j)]));
      Wire.write(0);
    }
    Wire.endTransmission();
    delay(delayN * 10);
  }

  gotoBed();
}

ISR(PCINT0_vect) {
  button = 1;
} // Button tap

ISR(WDT_vect) {
  //watchdog_counter++;
}
